.. module:: brownie.proxies

Proxies
=======

Implements proxies and facilities to create them.


.. versionadded:: 0.4


.. autofunction:: as_proxy

.. autofunction:: get_wrapped

.. autoclass:: LazyProxy
